==> kubernetes-model-core-5.11.1-sources.jar: io/fabric8/kubernetes/api/model/NodeConfigStatusFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class NodeConfigStatusFluentImpl<A extends io.fabric8.kubernetes.api.model.NodeConfigStatusFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.NodeConfigStatusFluent<A>{
  public NodeConfigStatusFluentImpl() {
  }
  public NodeConfigStatusFluentImpl(io.fabric8.kubernetes.api.model.NodeConfigStatus instance) {
    this.withActive(instance.getActive()); 
    this.withAssigned(instance.getAssigned()); 
    this.withError(instance.getError()); 
    this.withLastKnownGood(instance.getLastKnownGood()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private io.fabric8.kubernetes.api.model.NodeConfigSourceBuilder active;
  private io.fabric8.kubernetes.api.model.NodeConfigSourceBuilder assigned;
  private java.lang.String error;
  private io.fabric8.kubernetes.api.model.NodeConfigSourceBuilder lastKnownGood;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildActive instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.NodeConfigSource getActive() {
    return this.active!=null?this.active.build():null;
  }
  public io.fabric8.kubernetes.api.model.NodeConfigSource buildActive() {
    return this.active!=null?this.active.build():null;
  }
  public A withActive(io.fabric8.kubernetes.api.model.NodeConfigSource active) {
    _visitables.get("active").remove(this.active);
    if (active!=null){ this.active= new io.fabric8.kubernetes.api.model.NodeConfigSourceBuilder(active); _visitables.get("active").add(this.active);} return (A) this;
  }
  public java.lang.Boolean hasActive() {
    return this.active != null;
  }
  public io.fabric8.kubernetes.api.model.NodeConfigStatusFluent.ActiveNested<A> withNewActive() {
    return new io.fabric8.kubernetes.api.model.NodeConfigStatusFluentImpl.ActiveNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.NodeConfigStatusFluent.ActiveNested<A> withNewActiveLike(io.fabric8.kubernetes.api.model.NodeConfigSource item) {
    return new io.fabric8.kubernetes.api.model.NodeConfigStatusFluentImpl.ActiveNestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.NodeConfigStatusFluent.ActiveNested<A> editActive() {
    return withNewActiveLike(getActive());
  }
  public io.fabric8.kubernetes.api.model.NodeConfigStatusFluent.ActiveNested<A> editOrNewActive() {
    return withNewActiveLike(getActive() != null ? getActive(): new io.fabric8.kubernetes.api.model.NodeConfigSourceBuilder().build());
  }
  public io.fabric8.kubernetes.api.model.NodeConfigStatusFluent.ActiveNested<A> editOrNewActiveLike(io.fabric8.kubernetes.api.model.NodeConfigSource item) {
    return withNewActiveLike(getActive() != null ? getActive(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildAssigned instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.NodeConfigSource getAssigned() {
    return this.assigned!=null?this.assigned.build():null;
  }
  public io.fabric8.kubernetes.api.model.NodeConfigSource buildAssigned() {
    return this.assigned!=null?this.assigned.build():null;
  }
  public A withAssigned(io.fabric8.kubernetes.api.model.NodeConfigSource assigned) {
    _visitables.get("assigned").remove(this.assigned);
    if (assigned!=null){ this.assigned= new io.fabric8.kubernetes.api.model.NodeConfigSourceBuilder(assigned); _visitables.get("assigned").add(this.assigned);} return (A) this;
  }
  public java.lang.Boolean hasAssigned() {
    return this.assigned != null;
  }
  public io.fabric8.kubernetes.api.model.NodeConfigStatusFluent.AssignedNested<A> withNewAssigned() {
    return new io.fabric8.kubernetes.api.model.NodeConfigStatusFluentImpl.AssignedNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.NodeConfigStatusFluent.AssignedNested<A> withNewAssignedLike(io.fabric8.kubernetes.api.model.NodeConfigSource item) {
    return new io.fabric8.kubernetes.api.model.NodeConfigStatusFluentImpl.AssignedNestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.NodeConfigStatusFluent.AssignedNested<A> editAssigned() {
    return withNewAssignedLike(getAssigned());
  }
  public io.fabric8.kubernetes.api.model.NodeConfigStatusFluent.AssignedNested<A> editOrNewAssigned() {
    return withNewAssignedLike(getAssigned() != null ? getAssigned(): new io.fabric8.kubernetes.api.model.NodeConfigSourceBuilder().build());
  }
  public io.fabric8.kubernetes.api.model.NodeConfigStatusFluent.AssignedNested<A> editOrNewAssignedLike(io.fabric8.kubernetes.api.model.NodeConfigSource item) {
    return withNewAssignedLike(getAssigned() != null ? getAssigned(): item);
  }
  public java.lang.String getError() {
    return this.error;
  }
  public A withError(java.lang.String error) {
    this.error=error; return (A) this;
  }
  public java.lang.Boolean hasError() {
    return this.error != null;
  }
  
  /**
   * Method is deprecated. use withError instead.
   */
  @java.lang.Deprecated
  public A withNewError(java.lang.String arg0) {
    return (A)withError(new String(arg0));
  }
  
  /**
   * This method has been deprecated, please use method buildLastKnownGood instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.NodeConfigSource getLastKnownGood() {
    return this.lastKnownGood!=null?this.lastKnownGood.build():null;
  }
  public io.fabric8.kubernetes.api.model.NodeConfigSource buildLastKnownGood() {
    return this.lastKnownGood!=null?this.lastKnownGood.build():null;
  }
  public A withLastKnownGood(io.fabric8.kubernetes.api.model.NodeConfigSource lastKnownGood) {
    _visitables.get("lastKnownGood").remove(this.lastKnownGood);
    if (lastKnownGood!=null){ this.lastKnownGood= new io.fabric8.kubernetes.api.model.NodeConfigSourceBuilder(lastKnownGood); _visitables.get("lastKnownGood").add(this.lastKnownGood);} return (A) this;
  }
  public java.lang.Boolean hasLastKnownGood() {
    return this.lastKnownGood != null;
  }
  public io.fabric8.kubernetes.api.model.NodeConfigStatusFluent.LastKnownGoodNested<A> withNewLastKnownGood() {
    return new io.fabric8.kubernetes.api.model.NodeConfigStatusFluentImpl.LastKnownGoodNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.NodeConfigStatusFluent.LastKnownGoodNested<A> withNewLastKnownGoodLike(io.fabric8.kubernetes.api.model.NodeConfigSource item) {
    return new io.fabric8.kubernetes.api.model.NodeConfigStatusFluentImpl.LastKnownGoodNestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.NodeConfigStatusFluent.LastKnownGoodNested<A> editLastKnownGood() {
    return withNewLastKnownGoodLike(getLastKnownGood());
  }
  public io.fabric8.kubernetes.api.model.NodeConfigStatusFluent.LastKnownGoodNested<A> editOrNewLastKnownGood() {
    return withNewLastKnownGoodLike(getLastKnownGood() != null ? getLastKnownGood(): new io.fabric8.kubernetes.api.model.NodeConfigSourceBuilder().build());
  }
  public io.fabric8.kubernetes.api.model.NodeConfigStatusFluent.LastKnownGoodNested<A> editOrNewLastKnownGoodLike(io.fabric8.kubernetes.api.model.NodeConfigSource item) {
    return withNewLastKnownGoodLike(getLastKnownGood() != null ? getLastKnownGood(): item);
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    NodeConfigStatusFluentImpl that = (NodeConfigStatusFluentImpl) o;
    if (active != null ? !active.equals(that.active) :that.active != null) return false;
    if (assigned != null ? !assigned.equals(that.assigned) :that.assigned != null) return false;
    if (error != null ? !error.equals(that.error) :that.error != null) return false;
    if (lastKnownGood != null ? !lastKnownGood.equals(that.lastKnownGood) :that.lastKnownGood != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(active,  assigned,  error,  lastKnownGood,  additionalProperties,  super.hashCode());
  }
  public class ActiveNestedImpl<N> extends io.fabric8.kubernetes.api.model.NodeConfigSourceFluentImpl<io.fabric8.kubernetes.api.model.NodeConfigStatusFluent.ActiveNested<N>> implements io.fabric8.kubernetes.api.model.NodeConfigStatusFluent.ActiveNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    ActiveNestedImpl(io.fabric8.kubernetes.api.model.NodeConfigSource item) {
      this.builder = new io.fabric8.kubernetes.api.model.NodeConfigSourceBuilder(this, item);
    }
    ActiveNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.NodeConfigSourceBuilder(this);
    }
    io.fabric8.kubernetes.api.model.NodeConfigSourceBuilder builder;
    public N and() {
      return (N) NodeConfigStatusFluentImpl.this.withActive(builder.build());
    }
    public N endActive() {
      return and();
    }
    
  }
  public class AssignedNestedImpl<N> extends io.fabric8.kubernetes.api.model.NodeConfigSourceFluentImpl<io.fabric8.kubernetes.api.model.NodeConfigStatusFluent.AssignedNested<N>> implements io.fabric8.kubernetes.api.model.NodeConfigStatusFluent.AssignedNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    AssignedNestedImpl(io.fabric8.kubernetes.api.model.NodeConfigSource item) {
      this.builder = new io.fabric8.kubernetes.api.model.NodeConfigSourceBuilder(this, item);
    }
    AssignedNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.NodeConfigSourceBuilder(this);
    }
    io.fabric8.kubernetes.api.model.NodeConfigSourceBuilder builder;
    public N and() {
      return (N) NodeConfigStatusFluentImpl.this.withAssigned(builder.build());
    }
    public N endAssigned() {
      return and();
    }
    
  }
  public class LastKnownGoodNestedImpl<N> extends io.fabric8.kubernetes.api.model.NodeConfigSourceFluentImpl<io.fabric8.kubernetes.api.model.NodeConfigStatusFluent.LastKnownGoodNested<N>> implements io.fabric8.kubernetes.api.model.NodeConfigStatusFluent.LastKnownGoodNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    LastKnownGoodNestedImpl(io.fabric8.kubernetes.api.model.NodeConfigSource item) {
      this.builder = new io.fabric8.kubernetes.api.model.NodeConfigSourceBuilder(this, item);
    }
    LastKnownGoodNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.NodeConfigSourceBuilder(this);
    }
    io.fabric8.kubernetes.api.model.NodeConfigSourceBuilder builder;
    public N and() {
      return (N) NodeConfigStatusFluentImpl.this.withLastKnownGood(builder.build());
    }
    public N endLastKnownGood() {
      return and();
    }
    
  }
  
}

==> kubernetes-model-core-5.12.3-sources.jar: io/fabric8/kubernetes/api/model/NodeConfigStatusFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class NodeConfigStatusFluentImpl<A extends io.fabric8.kubernetes.api.model.NodeConfigStatusFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.NodeConfigStatusFluent<A>{
  public NodeConfigStatusFluentImpl() {
  }
  public NodeConfigStatusFluentImpl(io.fabric8.kubernetes.api.model.NodeConfigStatus instance) {
    this.withActive(instance.getActive()); 
    this.withAssigned(instance.getAssigned()); 
    this.withError(instance.getError()); 
    this.withLastKnownGood(instance.getLastKnownGood()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private io.fabric8.kubernetes.api.model.NodeConfigSourceBuilder active;
  private io.fabric8.kubernetes.api.model.NodeConfigSourceBuilder assigned;
  private java.lang.String error;
  private io.fabric8.kubernetes.api.model.NodeConfigSourceBuilder lastKnownGood;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildActive instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.NodeConfigSource getActive() {
    return this.active!=null?this.active.build():null;
  }
  public io.fabric8.kubernetes.api.model.NodeConfigSource buildActive() {
    return this.active!=null?this.active.build():null;
  }
  public A withActive(io.fabric8.kubernetes.api.model.NodeConfigSource active) {
    _visitables.get("active").remove(this.active);
    if (active!=null){ this.active= new io.fabric8.kubernetes.api.model.NodeConfigSourceBuilder(active); _visitables.get("active").add(this.active);} return (A) this;
  }
  public java.lang.Boolean hasActive() {
    return this.active != null;
  }
  public io.fabric8.kubernetes.api.model.NodeConfigStatusFluent.ActiveNested<A> withNewActive() {
    return new io.fabric8.kubernetes.api.model.NodeConfigStatusFluentImpl.ActiveNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.NodeConfigStatusFluent.ActiveNested<A> withNewActiveLike(io.fabric8.kubernetes.api.model.NodeConfigSource item) {
    return new io.fabric8.kubernetes.api.model.NodeConfigStatusFluentImpl.ActiveNestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.NodeConfigStatusFluent.ActiveNested<A> editActive() {
    return withNewActiveLike(getActive());
  }
  public io.fabric8.kubernetes.api.model.NodeConfigStatusFluent.ActiveNested<A> editOrNewActive() {
    return withNewActiveLike(getActive() != null ? getActive(): new io.fabric8.kubernetes.api.model.NodeConfigSourceBuilder().build());
  }
  public io.fabric8.kubernetes.api.model.NodeConfigStatusFluent.ActiveNested<A> editOrNewActiveLike(io.fabric8.kubernetes.api.model.NodeConfigSource item) {
    return withNewActiveLike(getActive() != null ? getActive(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildAssigned instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.NodeConfigSource getAssigned() {
    return this.assigned!=null?this.assigned.build():null;
  }
  public io.fabric8.kubernetes.api.model.NodeConfigSource buildAssigned() {
    return this.assigned!=null?this.assigned.build():null;
  }
  public A withAssigned(io.fabric8.kubernetes.api.model.NodeConfigSource assigned) {
    _visitables.get("assigned").remove(this.assigned);
    if (assigned!=null){ this.assigned= new io.fabric8.kubernetes.api.model.NodeConfigSourceBuilder(assigned); _visitables.get("assigned").add(this.assigned);} return (A) this;
  }
  public java.lang.Boolean hasAssigned() {
    return this.assigned != null;
  }
  public io.fabric8.kubernetes.api.model.NodeConfigStatusFluent.AssignedNested<A> withNewAssigned() {
    return new io.fabric8.kubernetes.api.model.NodeConfigStatusFluentImpl.AssignedNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.NodeConfigStatusFluent.AssignedNested<A> withNewAssignedLike(io.fabric8.kubernetes.api.model.NodeConfigSource item) {
    return new io.fabric8.kubernetes.api.model.NodeConfigStatusFluentImpl.AssignedNestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.NodeConfigStatusFluent.AssignedNested<A> editAssigned() {
    return withNewAssignedLike(getAssigned());
  }
  public io.fabric8.kubernetes.api.model.NodeConfigStatusFluent.AssignedNested<A> editOrNewAssigned() {
    return withNewAssignedLike(getAssigned() != null ? getAssigned(): new io.fabric8.kubernetes.api.model.NodeConfigSourceBuilder().build());
  }
  public io.fabric8.kubernetes.api.model.NodeConfigStatusFluent.AssignedNested<A> editOrNewAssignedLike(io.fabric8.kubernetes.api.model.NodeConfigSource item) {
    return withNewAssignedLike(getAssigned() != null ? getAssigned(): item);
  }
  public java.lang.String getError() {
    return this.error;
  }
  public A withError(java.lang.String error) {
    this.error=error; return (A) this;
  }
  public java.lang.Boolean hasError() {
    return this.error != null;
  }
  
  /**
   * Method is deprecated. use withError instead.
   */
  @java.lang.Deprecated
  public A withNewError(java.lang.String arg0) {
    return (A)withError(new String(arg0));
  }
  
  /**
   * This method has been deprecated, please use method buildLastKnownGood instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.NodeConfigSource getLastKnownGood() {
    return this.lastKnownGood!=null?this.lastKnownGood.build():null;
  }
  public io.fabric8.kubernetes.api.model.NodeConfigSource buildLastKnownGood() {
    return this.lastKnownGood!=null?this.lastKnownGood.build():null;
  }
  public A withLastKnownGood(io.fabric8.kubernetes.api.model.NodeConfigSource lastKnownGood) {
    _visitables.get("lastKnownGood").remove(this.lastKnownGood);
    if (lastKnownGood!=null){ this.lastKnownGood= new io.fabric8.kubernetes.api.model.NodeConfigSourceBuilder(lastKnownGood); _visitables.get("lastKnownGood").add(this.lastKnownGood);} return (A) this;
  }
  public java.lang.Boolean hasLastKnownGood() {
    return this.lastKnownGood != null;
  }
  public io.fabric8.kubernetes.api.model.NodeConfigStatusFluent.LastKnownGoodNested<A> withNewLastKnownGood() {
    return new io.fabric8.kubernetes.api.model.NodeConfigStatusFluentImpl.LastKnownGoodNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.NodeConfigStatusFluent.LastKnownGoodNested<A> withNewLastKnownGoodLike(io.fabric8.kubernetes.api.model.NodeConfigSource item) {
    return new io.fabric8.kubernetes.api.model.NodeConfigStatusFluentImpl.LastKnownGoodNestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.NodeConfigStatusFluent.LastKnownGoodNested<A> editLastKnownGood() {
    return withNewLastKnownGoodLike(getLastKnownGood());
  }
  public io.fabric8.kubernetes.api.model.NodeConfigStatusFluent.LastKnownGoodNested<A> editOrNewLastKnownGood() {
    return withNewLastKnownGoodLike(getLastKnownGood() != null ? getLastKnownGood(): new io.fabric8.kubernetes.api.model.NodeConfigSourceBuilder().build());
  }
  public io.fabric8.kubernetes.api.model.NodeConfigStatusFluent.LastKnownGoodNested<A> editOrNewLastKnownGoodLike(io.fabric8.kubernetes.api.model.NodeConfigSource item) {
    return withNewLastKnownGoodLike(getLastKnownGood() != null ? getLastKnownGood(): item);
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    NodeConfigStatusFluentImpl that = (NodeConfigStatusFluentImpl) o;
    if (active != null ? !active.equals(that.active) :that.active != null) return false;
    if (assigned != null ? !assigned.equals(that.assigned) :that.assigned != null) return false;
    if (error != null ? !error.equals(that.error) :that.error != null) return false;
    if (lastKnownGood != null ? !lastKnownGood.equals(that.lastKnownGood) :that.lastKnownGood != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(active,  assigned,  error,  lastKnownGood,  additionalProperties,  super.hashCode());
  }
  public class ActiveNestedImpl<N> extends io.fabric8.kubernetes.api.model.NodeConfigSourceFluentImpl<io.fabric8.kubernetes.api.model.NodeConfigStatusFluent.ActiveNested<N>> implements io.fabric8.kubernetes.api.model.NodeConfigStatusFluent.ActiveNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    ActiveNestedImpl(io.fabric8.kubernetes.api.model.NodeConfigSource item) {
      this.builder = new io.fabric8.kubernetes.api.model.NodeConfigSourceBuilder(this, item);
    }
    ActiveNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.NodeConfigSourceBuilder(this);
    }
    io.fabric8.kubernetes.api.model.NodeConfigSourceBuilder builder;
    public N and() {
      return (N) NodeConfigStatusFluentImpl.this.withActive(builder.build());
    }
    public N endActive() {
      return and();
    }
    
  }
  public class AssignedNestedImpl<N> extends io.fabric8.kubernetes.api.model.NodeConfigSourceFluentImpl<io.fabric8.kubernetes.api.model.NodeConfigStatusFluent.AssignedNested<N>> implements io.fabric8.kubernetes.api.model.NodeConfigStatusFluent.AssignedNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    AssignedNestedImpl(io.fabric8.kubernetes.api.model.NodeConfigSource item) {
      this.builder = new io.fabric8.kubernetes.api.model.NodeConfigSourceBuilder(this, item);
    }
    AssignedNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.NodeConfigSourceBuilder(this);
    }
    io.fabric8.kubernetes.api.model.NodeConfigSourceBuilder builder;
    public N and() {
      return (N) NodeConfigStatusFluentImpl.this.withAssigned(builder.build());
    }
    public N endAssigned() {
      return and();
    }
    
  }
  public class LastKnownGoodNestedImpl<N> extends io.fabric8.kubernetes.api.model.NodeConfigSourceFluentImpl<io.fabric8.kubernetes.api.model.NodeConfigStatusFluent.LastKnownGoodNested<N>> implements io.fabric8.kubernetes.api.model.NodeConfigStatusFluent.LastKnownGoodNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    LastKnownGoodNestedImpl(io.fabric8.kubernetes.api.model.NodeConfigSource item) {
      this.builder = new io.fabric8.kubernetes.api.model.NodeConfigSourceBuilder(this, item);
    }
    LastKnownGoodNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.NodeConfigSourceBuilder(this);
    }
    io.fabric8.kubernetes.api.model.NodeConfigSourceBuilder builder;
    public N and() {
      return (N) NodeConfigStatusFluentImpl.this.withLastKnownGood(builder.build());
    }
    public N endLastKnownGood() {
      return and();
    }
    
  }
  
}
